<?php
// $Id: views_rotator.views.inc,v 1.2 2008/08/24 00:06:44 mfer Exp $
/**
 * @file
 * Provide a rotating item display style for Views. This file is autoloaded by views.
 */

/**
  * Implementation of hook_views_plugin().
  */
function views_rotator_views_plugins() {
  return array(
    'style' => array(
      'views_rotator' => array(
        'title' => t('Views Rotator'),
        'theme' => 'views_view_rotator',
        'help' => t('Display one node at a time while rotating through them.'),
        'handler' => 'views_plugin_style_rotator',
        'uses row plugin' => TRUE,
        'uses options' => TRUE,
        'type' => 'normal',
      ),
    ),
  );
}

/**
  * Implementation of views_plugin_style().
  */
class views_plugin_style_rotator extends views_plugin_style {

  /**
   * Set default options
   */
  function options(&$options) {
    $options['timeout'] = 5;
    $options['speed'] = 1;
    $options['pause'] = 0;
    $options['back_next_buttons'] = 0;
    $options['height'] = 'auto';
  }

  function options_form(&$form, &$form_state) {
    $form['timeout'] = array(
      '#type' => 'textfield',
      '#title' => t('Time between displaying items'),
      '#size' => 10,
      '#maxlength' => 60,
      '#default_value' => $this->options['timeout'],
      '#description' => t('The time in seconds.'),
    );
    $form['speed'] = array(
      '#type' => 'textfield',
      '#title' => t('Time for the transition'),
      '#size' => 10,
      '#maxlength' => 60,
      '#default_value' => $this->options['speed'],
      '#description' => t('The time in seconds.'),
    );
    $form['pause'] = array(
      '#type' => 'checkbox',
      '#title' => t('Pause rotation when the mouse is over the area.'),
      '#default_value' => $this->options['pause'],
    );
    $form['back_next_buttons'] = array(
      '#type' => 'checkbox',
      '#title' => t('Display back and next buttons when the mouse is over the area.'),
      '#default_value' => $this->options['back_next_buttons'],
    );
    $form['height'] = array(
      '#type' => 'textfield',
      '#title' => t('Height of container'),
      '#size' => 10,
      '#maxlength' => 60,
      '#default_value' => $this->options['height'],
      '#description' => t('If the height is left empty the style will default to auto height. Enter px or em as part of the size.'),
    );
  }
}

/**
 * Only returns true the first time it's called for an id
 *
 * @param $id
 *  A uniqe view id.
 *
 * @return bool
 *  TRUE for the first time called for a given $id
 *  FALSE for each time after that
 */
function views_rotator_display_item($id) {
  static $display = array();

  if (!isset($display[$id])) $display[$id] = FALSE;

  $output = $display[$id];

  if ($display[$id] == FALSE) $display[$id] = TRUE;

  return $output;
}


function template_preprocess_views_view_rotator(&$vars) {
  drupal_add_css(drupal_get_path('module', 'views_rotator') .'/views-rotator.css');

  $view = $vars['view'];
  $options = $view->style_plugin->options;

  $vars['views_rotator_id'] = 'views-rotator-'. $view->name .'-'. $view->current_display;

  drupal_add_js(drupal_get_path('module', 'views_rotator') .'/views-rotator.js');

  $view_settings['fx'] = 'fade';
  $view_settings['height'] = check_plain($options['height']);
  $view_settings['timeout'] = check_plain($options['timeout']) * 1000;
  $view_settings['speed'] = check_plain($options['speed']) * 1000;
  $view_settings['pause'] = check_plain($options['pause']);
  $view_settings['cleartype'] = 1;
  if (!empty($options['back_next_buttons'])) {
    $view_settings['next'] = '#'. $vars['views_rotator_id'] .'-views-rotator-next';
    $view_settings['prev'] = '#'. $vars['views_rotator_id'] .'-views-rotator-prev';
  }

  drupal_add_js(array('views_rotator' => array($vars['views_rotator_id'] => $view_settings)), 'setting');
}